==> haskell-bytestring-encoding-0.1.2.0-145-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bytestring-encoding.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bytestring-encoding
version:              0.1.2.0
visibility:           public
id:                   bytestring-encoding-0.1.2.0-KyMQELQxcWWCpwXwEXRUAc
key:                  bytestring-encoding-0.1.2.0-KyMQELQxcWWCpwXwEXRUAc
license:              BSD-3-Clause
copyright:            2018 Masahiro Sakai
maintainer:           masahiro.sakai@gmail.com
author:               Masahiro Sakai
homepage:             https://github.com/msakai/bytestring-encoding#readme
synopsis:             ByteString ↔ Text converter based on GHC.IO.Encoding
description:
    Please see the README on GitHub at <https://github.com/msakai/bytestring-encoding#readme>

category:             Data, Text
abi:                  dded5036e30e34316380f5a54f5c8811
exposed:              True
exposed-modules:
    Data.ByteString.Encoding Data.ByteString.Lazy.Encoding
    Data.ByteString.Lazy.Encoding.Internal

hidden-modules:       Paths_bytestring_encoding
import-dirs:          /usr/lib/ghc-9.4.8/site-local/bytestring-encoding-0.1.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bytestring-encoding-0.1.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bytestring-encoding-0.1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bytestring-encoding
hs-libraries:         HSbytestring-encoding-0.1.2.0-KyMQELQxcWWCpwXwEXRUAc
depends:              base-4.17.2.1 bytestring-0.11.5.3 text-2.0.2
haddock-interfaces:
    /usr/share/doc/haskell-bytestring-encoding/html/bytestring-encoding.haddock

haddock-html:         /usr/share/doc/haskell-bytestring-encoding/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bytestring-encoding-0.1.2.0-146-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bytestring-encoding.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bytestring-encoding
version:              0.1.2.0
visibility:           public
id:                   bytestring-encoding-0.1.2.0-GwRZjhYy0LCHNNhKVt5nxh
key:                  bytestring-encoding-0.1.2.0-GwRZjhYy0LCHNNhKVt5nxh
license:              BSD-3-Clause
copyright:            2018 Masahiro Sakai
maintainer:           masahiro.sakai@gmail.com
author:               Masahiro Sakai
homepage:             https://github.com/msakai/bytestring-encoding#readme
synopsis:             ByteString ↔ Text converter based on GHC.IO.Encoding
description:
    Please see the README on GitHub at <https://github.com/msakai/bytestring-encoding#readme>

category:             Data, Text
abi:                  196f47bf799cc0da74b07be78e42d988
exposed:              True
exposed-modules:
    Data.ByteString.Encoding Data.ByteString.Lazy.Encoding
    Data.ByteString.Lazy.Encoding.Internal

hidden-modules:       Paths_bytestring_encoding
import-dirs:          /usr/lib/ghc-9.4.8/site-local/bytestring-encoding-0.1.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bytestring-encoding-0.1.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bytestring-encoding-0.1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bytestring-encoding
hs-libraries:         HSbytestring-encoding-0.1.2.0-GwRZjhYy0LCHNNhKVt5nxh
depends:              base-4.17.2.1 bytestring-0.11.5.3 text-2.0.2
haddock-interfaces:
    /usr/share/doc/haskell-bytestring-encoding/html/bytestring-encoding.haddock

haddock-html:         /usr/share/doc/haskell-bytestring-encoding/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
